# Copyright (c) 2017-2020, National Technology & Engineering Solutions of
#   Sandia, LLC (NTESS).
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

"""tracktable.io - Alias of tracktable.rw
"""

# TODO (mjfadem): Remove this file in release 1.6

import warnings
import sys
import tracktable.rw
import tracktable.rw.point
import tracktable.rw.read_write_dictionary
import tracktable.rw.read_write_json

# This just stops the source line from printing with the warning
def format_warning(message, category, filename, lineno, file=None, line=None):
    return '%s:%s: %s:%s\n' % (filename, lineno, category.__name__, message)

warnings.formatwarning = format_warning

# Allow the PendingDeprecationWarning through since it's disabled by default
warnings.simplefilter("always", category=PendingDeprecationWarning)

# This will display a PendingDeprecationWarning when the IO module is imported
warnings.warn(" The tracktable.io module will be be renamed to tracktable.rw in release 1.6.", category=PendingDeprecationWarning)

# Aliases to smooth the transition of tracktable.io to tracktable.rw renaming
sys.modules['tracktable.io'] = tracktable.rw
sys.modules['tracktable.io.point'] = tracktable.rw.point
sys.modules['tracktable.io.read_write_dictionary'] = tracktable.rw.read_write_dictionary
sys.modules['tracktable.io.read_write_json'] = tracktable.rw.read_write_json
